==> rasqal_0.9.17.orig.tar.gz: rasqal-0.9.17/src/sparql_parser.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SELECT = 258,
     FROM = 259,
     WHERE = 260,
     OPTIONAL = 261,
     DESCRIBE = 262,
     CONSTRUCT = 263,
     ASK = 264,
     DISTINCT = 265,
     REDUCED = 266,
     LIMIT = 267,
     UNION = 268,
     PREFIX = 269,
     BASE = 270,
     BOUND = 271,
     GRAPH = 272,
     NAMED = 273,
     FILTER = 274,
     OFFSET = 275,
     ORDER = 276,
     BY = 277,
     REGEX = 278,
     ASC = 279,
     DESC = 280,
     LANGMATCHES = 281,
     A = 282,
     STR = 283,
     LANG = 284,
     DATATYPE = 285,
     ISURI = 286,
     ISBLANK = 287,
     ISLITERAL = 288,
     SAMETERM = 289,
     EXPLAIN = 290,
     GROUP = 291,
     COUNT = 292,
     SUM = 293,
     AVG = 294,
     MIN = 295,
     MAX = 296,
     AS = 297,
     DELETE = 298,
     INSERT = 299,
     LET = 300,
     COALESCE = 301,
     SC_OR = 302,
     SC_AND = 303,
     EQ = 304,
     NEQ = 305,
     LT = 306,
     GT = 307,
     LE = 308,
     GE = 309,
     ASSIGN = 310,
     STRING_LITERAL = 311,
     DOUBLE_LITERAL = 312,
     DOUBLE_POSITIVE_LITERAL = 313,
     DOUBLE_NEGATIVE_LITERAL = 314,
     INTEGER_LITERAL = 315,
     INTEGER_POSITIVE_LITERAL = 316,
     INTEGER_NEGATIVE_LITERAL = 317,
     DECIMAL_LITERAL = 318,
     DECIMAL_POSITIVE_LITERAL = 319,
     DECIMAL_NEGATIVE_LITERAL = 320,
     BOOLEAN_LITERAL = 321,
     URI_LITERAL = 322,
     URI_LITERAL_BRACE = 323,
     QNAME_LITERAL = 324,
     QNAME_LITERAL_BRACE = 325,
     BLANK_LITERAL = 326,
     IDENTIFIER = 327
   };
#endif
/* Tokens.  */
#define SELECT 258
#define FROM 259
#define WHERE 260
#define OPTIONAL 261
#define DESCRIBE 262
#define CONSTRUCT 263
#define ASK 264
#define DISTINCT 265
#define REDUCED 266
#define LIMIT 267
#define UNION 268
#define PREFIX 269
#define BASE 270
#define BOUND 271
#define GRAPH 272
#define NAMED 273
#define FILTER 274
#define OFFSET 275
#define ORDER 276
#define BY 277
#define REGEX 278
#define ASC 279
#define DESC 280
#define LANGMATCHES 281
#define A 282
#define STR 283
#define LANG 284
#define DATATYPE 285
#define ISURI 286
#define ISBLANK 287
#define ISLITERAL 288
#define SAMETERM 289
#define EXPLAIN 290
#define GROUP 291
#define COUNT 292
#define SUM 293
#define AVG 294
#define MIN 295
#define MAX 296
#define AS 297
#define DELETE 298
#define INSERT 299
#define LET 300
#define COALESCE 301
#define SC_OR 302
#define SC_AND 303
#define EQ 304
#define NEQ 305
#define LT 306
#define GT 307
#define LE 308
#define GE 309
#define ASSIGN 310
#define STRING_LITERAL 311
#define DOUBLE_LITERAL 312
#define DOUBLE_POSITIVE_LITERAL 313
#define DOUBLE_NEGATIVE_LITERAL 314
#define INTEGER_LITERAL 315
#define INTEGER_POSITIVE_LITERAL 316
#define INTEGER_NEGATIVE_LITERAL 317
#define DECIMAL_LITERAL 318
#define DECIMAL_POSITIVE_LITERAL 319
#define DECIMAL_NEGATIVE_LITERAL 320
#define BOOLEAN_LITERAL 321
#define URI_LITERAL 322
#define URI_LITERAL_BRACE 323
#define QNAME_LITERAL 324
#define QNAME_LITERAL_BRACE 325
#define BLANK_LITERAL 326
#define IDENTIFIER 327




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 114 "./sparql_parser.y"

  raptor_sequence *seq;
  rasqal_variable *variable;
  rasqal_literal *literal;
  rasqal_triple *triple;
  rasqal_expression *expr;
  rasqal_graph_pattern *graph_pattern;
  double floating;
  raptor_uri *uri;
  unsigned char *name;
  rasqal_formula *formula;



/* Line 1676 of yacc.c  */
#line 211 "sparql_parser.tab.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

==> rasqal_0.9.19.orig.tar.gz: rasqal-0.9.19/src/sparql_parser.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SELECT = 258,
     FROM = 259,
     WHERE = 260,
     OPTIONAL = 261,
     DESCRIBE = 262,
     CONSTRUCT = 263,
     ASK = 264,
     DISTINCT = 265,
     REDUCED = 266,
     LIMIT = 267,
     UNION = 268,
     PREFIX = 269,
     BASE = 270,
     BOUND = 271,
     GRAPH = 272,
     NAMED = 273,
     FILTER = 274,
     OFFSET = 275,
     ORDER = 276,
     BY = 277,
     REGEX = 278,
     ASC = 279,
     DESC = 280,
     LANGMATCHES = 281,
     A = 282,
     STR = 283,
     LANG = 284,
     DATATYPE = 285,
     ISURI = 286,
     ISBLANK = 287,
     ISLITERAL = 288,
     SAMETERM = 289,
     GROUP = 290,
     COUNT = 291,
     SUM = 292,
     AVG = 293,
     MIN = 294,
     MAX = 295,
     DELETE = 296,
     INSERT = 297,
     WITH = 298,
     CLEAR = 299,
     CREATE = 300,
     SILENT = 301,
     DATA = 302,
     DROP = 303,
     LOAD = 304,
     INTO = 305,
     EXPLAIN = 306,
     LET = 307,
     AS = 308,
     COALESCE = 309,
     SC_OR = 310,
     SC_AND = 311,
     EQ = 312,
     NEQ = 313,
     LT = 314,
     GT = 315,
     LE = 316,
     GE = 317,
     ASSIGN = 318,
     STRING_LITERAL = 319,
     DOUBLE_LITERAL = 320,
     DOUBLE_POSITIVE_LITERAL = 321,
     DOUBLE_NEGATIVE_LITERAL = 322,
     INTEGER_LITERAL = 323,
     INTEGER_POSITIVE_LITERAL = 324,
     INTEGER_NEGATIVE_LITERAL = 325,
     DECIMAL_LITERAL = 326,
     DECIMAL_POSITIVE_LITERAL = 327,
     DECIMAL_NEGATIVE_LITERAL = 328,
     BOOLEAN_LITERAL = 329,
     URI_LITERAL = 330,
     URI_LITERAL_BRACE = 331,
     QNAME_LITERAL = 332,
     QNAME_LITERAL_BRACE = 333,
     BLANK_LITERAL = 334,
     IDENTIFIER = 335
   };
#endif
/* Tokens.  */
#define SELECT 258
#define FROM 259
#define WHERE 260
#define OPTIONAL 261
#define DESCRIBE 262
#define CONSTRUCT 263
#define ASK 264
#define DISTINCT 265
#define REDUCED 266
#define LIMIT 267
#define UNION 268
#define PREFIX 269
#define BASE 270
#define BOUND 271
#define GRAPH 272
#define NAMED 273
#define FILTER 274
#define OFFSET 275
#define ORDER 276
#define BY 277
#define REGEX 278
#define ASC 279
#define DESC 280
#define LANGMATCHES 281
#define A 282
#define STR 283
#define LANG 284
#define DATATYPE 285
#define ISURI 286
#define ISBLANK 287
#define ISLITERAL 288
#define SAMETERM 289
#define GROUP 290
#define COUNT 291
#define SUM 292
#define AVG 293
#define MIN 294
#define MAX 295
#define DELETE 296
#define INSERT 297
#define WITH 298
#define CLEAR 299
#define CREATE 300
#define SILENT 301
#define DATA 302
#define DROP 303
#define LOAD 304
#define INTO 305
#define EXPLAIN 306
#define LET 307
#define AS 308
#define COALESCE 309
#define SC_OR 310
#define SC_AND 311
#define EQ 312
#define NEQ 313
#define LT 314
#define GT 315
#define LE 316
#define GE 317
#define ASSIGN 318
#define STRING_LITERAL 319
#define DOUBLE_LITERAL 320
#define DOUBLE_POSITIVE_LITERAL 321
#define DOUBLE_NEGATIVE_LITERAL 322
#define INTEGER_LITERAL 323
#define INTEGER_POSITIVE_LITERAL 324
#define INTEGER_NEGATIVE_LITERAL 325
#define DECIMAL_LITERAL 326
#define DECIMAL_POSITIVE_LITERAL 327
#define DECIMAL_NEGATIVE_LITERAL 328
#define BOOLEAN_LITERAL 329
#define URI_LITERAL 330
#define URI_LITERAL_BRACE 331
#define QNAME_LITERAL 332
#define QNAME_LITERAL_BRACE 333
#define BLANK_LITERAL 334
#define IDENTIFIER 335




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 114 "./sparql_parser.y"

  raptor_sequence *seq;
  rasqal_variable *variable;
  rasqal_literal *literal;
  rasqal_triple *triple;
  rasqal_expression *expr;
  rasqal_graph_pattern *graph_pattern;
  double floating;
  raptor_uri *uri;
  unsigned char *name;
  rasqal_formula *formula;
  rasqal_update_operation *update;



/* Line 1676 of yacc.c  */
#line 228 "sparql_parser.tab.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif
